Learn R Programming

ura (version 1.0.1)

ura-package: ura: Monitoring Rater Reliability

Description

Provides researchers with a simple set of diagnostic tools for monitoring the progress and reliability of raters conducting content coding tasks. Goehring (2024) https://bengoehring.github.io/improving-content-analysis-tools-for-working-with-undergraduate-research-assistants.pdf argues that supervisors---especially supervisors of small teams---should utilize computational tools to monitor reliability in real time. As such, this package provides easy-to-use functions for calculating inter-rater reliability statistics and measuring the reliability of one coder compared to the rest of the team.

Arguments

Author

Maintainer: Benjamin Goehring bengoehr@umich.edu (ORCID)

See Also